@@ -25,7 +25,7 @@ __author__ = "Ran Aroussi"
 from .ticker import Ticker
 from .tickers import Tickers
 from .multi import download
-from .multi import Resolver, StockResolver, OptionResolver
+from .multi import Resolver, StockResolver, OptionResolver, FundamentalResolver, ForexResolver, CoreResolver, EurConvertingResolver, DataframeResolver, EURStockResolver, PathResolver
 
 
 def pdr_override():
